"""
    Copyright (C) 2017-2018 Team Kodi
    This file is part of Kodi - kodi.tv

    SPDX-License-Identifier: GPL-3.0-only
    See LICENSES/README.md for more information.
"""

__version__ = "0.0.23"

ValidKodiVersions = [
    "gotham",
    "helix",
    "isengard",
    "jarvis",
    "krypton",
    "leia",
    "matrix",
]
